@@ -7,7 +7,7 @@ use File::Slurp;
 use Org::Document;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 sub parse {
     my ($self, $arg) = @_;
@@ -51,7 +51,7 @@ Org::Parser - Parse Org documents
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,8 @@ will print something like:
  heading level 1: heading1b
  heading level 1: heading1c
 
-A command-line utility is provided for debugging:
+A command-line utility (in a separate distribution: L<App::OrgUtils>) is
+available for debugging:
 
  % dump-org-structure ~/todo.org
  Document:
@@ -155,6 +156,22 @@ Will die if there are syntax errors in documents.
 
 Just like parse(), but will load document from file instead.
 
+=head1 FAQ
+
+=head2 Why? Just as only perl can parse Perl, only org-mode can parse Org anyway!
+
+True. I'm only targetting good enough. As long as I can parse/process all my Org
+notes and todo files, I have no complaints.
+
+=head2 It's too slow!
+
+Startup is a tad slow (but still under 0.5-1 s), due to having to load largish
+modules like DateTime.
+
+Parser is completely regex-based at the moment (I plan to use L<Marpa> someday).
+Performance is not great but I'm not annoyed enough at the moment to overhaul
+it.
+
 =head1 SEE ALSO
 
 L<Org::Document>
